@@ -38,6 +38,8 @@ trait PlotTrait {
     fn iter_second(&mut self) -> &mut dyn Iterator<Item = [f64; 2]>;
 }
 
+
+
 use fmt::Display;
 struct PlotStruct<I: Iterator<Item = [f64; 2]> + Clone, F: Display> {
     first: I,
@@ -296,6 +298,8 @@ pub struct Plotter<'a> {
     xname: Box<dyn fmt::Display + 'a>,
     yname: Box<dyn fmt::Display + 'a>,
     plots: Vec<Plot<'a>>,
+    xmarkers:Vec<f64>,
+    ymarkers:Vec<f64>
 }
 
 impl<'a> Plotter<'a> {
@@ -318,6 +322,8 @@ impl<'a> Plotter<'a> {
             xname: Box::new(xname),
             yname: Box::new(yname),
             plots: Vec::new(),
+            xmarkers:Vec::new(),
+            ymarkers:Vec::new()
         }
     }
     /// Create a line from plots using a SVG polyline element.
@@ -419,6 +425,37 @@ impl<'a> Plotter<'a> {
         self
     }
 
+
+    /// Add x values that the scaled graph must fit.
+    ///
+    /// ```
+    /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
+    /// let mut plotter = poloto::plot("title", "x", "y");
+    /// plotter.line("", &data);
+    /// 
+    /// // Include origin in the graph.
+    /// plotter.xmarker(0).ymarker(0);
+    /// ```
+    pub fn xmarker<A:std::borrow::Borrow<B>,B:AsF64>(&mut self,marker:A)->&mut Self{
+        self.xmarkers.push(marker.borrow().as_f64());
+        self
+    }
+    
+    /// Add y values that the scaled graph must fit.
+    /// 
+    /// ```
+    /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
+    /// let mut plotter = poloto::plot("title", "x", "y");
+    /// plotter.line("", &data);
+    /// 
+    /// // Include origin in the graph.
+    /// plotter.xmarker(0).ymarker(0);
+    /// ```
+    pub fn ymarker<A:std::borrow::Borrow<B>,B:AsF64>(&mut self,marker:A)->&mut Self{
+        self.ymarkers.push(marker.borrow().as_f64());
+        self
+    }
+
     ///
     /// Use the plot iterators and generate out a [`tagger::Element`] which implements [`std::fmt::Display`]
     ///
@@ -449,4 +486,5 @@ impl<'a> Plotter<'a> {
     pub fn try_render(&mut self) -> Result<tagger::Element<'a>, fmt::Error> {
         render::render(self)
     }
+
 }
