@@ -12,12 +12,16 @@ pub fn render<'b>(plotter: &mut Plotter<'b>) -> Result<tagger::Element<'b>, fmt:
     let mut xname: Box<dyn fmt::Display> = Box::new("");
     let mut yname: Box<dyn fmt::Display> = Box::new("");
     let mut plots = Vec::new();
+    let mut xmarkers=Vec::new();
+    let mut ymarkers=Vec::new();
 
     core::mem::swap(&mut element, &mut plotter.element);
     core::mem::swap(&mut title, &mut plotter.title);
     core::mem::swap(&mut xname, &mut plotter.xname);
     core::mem::swap(&mut yname, &mut plotter.yname);
     core::mem::swap(&mut plots, &mut plotter.plots);
+    core::mem::swap(&mut xmarkers, &mut plotter.xmarkers);
+    core::mem::swap(&mut ymarkers, &mut plotter.ymarkers);
 
     let mut svg = element;
 
@@ -42,6 +46,8 @@ pub fn render<'b>(plotter: &mut Plotter<'b>) -> Result<tagger::Element<'b>, fmt:
         plots
             .iter_mut()
             .flat_map(|x| x.plots.iter_first().map(|[x, y]| [x as f64, y as f64])),
+        xmarkers,
+        ymarkers,
     ) {
         m
     } else {
@@ -216,16 +222,24 @@ pub fn render<'b>(plotter: &mut Plotter<'b>) -> Result<tagger::Element<'b>, fmt:
                 }
 
                 let mut path = tagger::path_builder();
-                use tagger::PathCommand::*;
-                path.add(M(padding, height - paddingy));
+                
+                let mut it=it;
+                if let Some([startx,starty])=it.next(){
+                    use tagger::PathCommand::*;
+                    path.add(M(startx, height - paddingy));
+                    path.add(L(startx,starty));
+                    let mut final_x=startx;
 
-                for [x, y] in it {
-                    path.add(L(x, y));
+                    for [x, y] in it {
+                        path.add(L(x, y));
+                        final_x=x;
+                    }
+                    path.add(L(final_x, height - paddingy));
+                    path.add(Z(""));
                 }
 
-                path.add(L(width - padding, height - paddingy));
-                path.add(Z(""));
-
+                
+                
                 let d = attr_builder()
                     .attr("class", formatm!("poloto{}fill", colori))
                     .attr_whole(path.build())
@@ -234,8 +248,6 @@ pub fn render<'b>(plotter: &mut Plotter<'b>) -> Result<tagger::Element<'b>, fmt:
             }
         }
 
-        //let name = format!("{}", tagger::moveable_format(|w| { plots.write_name(w) }));
-        //let name_exists = !name.is_empty();
         let name = tagger::moveable_format(move |w| plots.write_name(w));
 
         let d = attr_builder()
